Learn R Programming

catsim (version 0.2.4)

besag: A hand-constructed image from Besag (1986)

Description

An \(100 \times 88\) matrix representing a two-color hand-drawn scene designed specifically to contain some awkward features for an image reconstruction method evaluated in the paper.

Usage

data(besag)

Arguments

Format

an \(100 \times 88\) matrix with entries 1 and 2 denoting the color of the corresponding pixels. The example code will produce the image as it is in the original paper. To use as a 0-1 binary dataset, either use besag - 1 or besag %% 2.

References

J. Besag, “On the statistical analysis of dirty pictures,” Journal of the Royal Statistical Society: Series B (Methodological), vol. 48, no. 3, pp. 259–279, 1986. tools:::Rd_expr_doi("10.1111/j.2517-6161.1986.tb01412.x")

Examples

Run this code
image(besag[, 88:1])

Run the code above in your browser using DataLab